@@ -5,30 +5,29 @@ Dependency handler
 
 :author: Thomas Calmant
 :copyright: Copyright 2013, isandlaTech
-:license: GPLv3
-:version: 0.5.4
-:status: Alpha
+:license: Apache License 2.0
+:version: 0.5.5
+:status: Beta
 
 ..
 
-    This file is part of iPOPO.
+    Copyright 2013 isandlaTech
 
-    iPOPO is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
+    Licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
+    You may obtain a copy of the License at
 
-    iPOPO is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    You should have received a copy of the GNU General Public License
-    along with iPOPO. If not, see <http://www.gnu.org/licenses/>.
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
 """
 
 # Module version
-__version_info__ = (0, 5, 4)
+__version_info__ = (0, 5, 5)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -41,7 +40,8 @@ from pelix.constants import BundleException
 from pelix.internals.events import ServiceEvent
 
 # iPOPO constants
-import pelix.ipopo.constants as constants
+import pelix.ipopo.constants as ipopo_constants
+import pelix.ipopo.handlers.constants as constants
 
 # Standard library
 import logging
@@ -49,29 +49,128 @@ import threading
 
 # ------------------------------------------------------------------------------
 
-class _RuntimeDependency(object):
+class _HandlerFactory(constants.HandlerFactory):
+    """
+    Factory service for service registration handlers
+    """
+    def _prepare_requirements(self, requirements, requires_filters):
+        """
+        """
+        if not requires_filters or not isinstance(requires_filters, dict):
+            # No explicit filter configured
+            return requirements
+
+        # We need to change a part of the requirements
+        new_requirements = {}
+        for field, requirement in requirements.items():
+            try:
+                explicit_filter = requires_filters[field]
+
+                # Store an updated copy of the requirement
+                requirement_copy = requirement.copy()
+                requirement_copy.set_filter(explicit_filter)
+                new_requirements[field] = requirement_copy
+
+            except (KeyError, TypeError, ValueError):
+                # No information for this one, or invalid filter:
+                # keep the factory requirement
+                new_requirements[field] = requirement
+
+        return new_requirements
+
+
+    def get_handlers(self, component_context, instance):
+        """
+        Sets up service providers for the given component
+
+        :param component_context: The ComponentContext bean
+        :param instance: The component instance
+        :return: The list of handlers associated to the given component
+        """
+        # Extract information from the context
+        requirements = component_context.get_handler(
+                                         ipopo_constants.HANDLER_REQUIRES)
+        requires_filters = component_context.properties.get(
+                                         ipopo_constants.IPOPO_REQUIRES_FILTERS,
+                                         None)
+
+        # Prepare requirements
+        requirements = self._prepare_requirements(requirements,
+                                                  requires_filters)
+
+        # Set up the runtime dependency handlers
+        handlers = []
+        for field, requirement in requirements.items():
+            # Construct the handler
+            if requirement.aggregate:
+                handlers.append(AggregateDependency(field, requirement))
+            else:
+                handlers.append(SimpleDependency(field, requirement))
+
+        return handlers
+
+
+class _Activator(object):
+    """
+    The bundle activator
+    """
+    def __init__(self):
+        """
+        Sets up members
+        """
+        self._registration = None
+
+
+    def start(self, context):
+        """
+        Bundle started
+        """
+        # Set up properties
+        properties = {constants.PROP_HANDLER_ID:
+                      ipopo_constants.HANDLER_REQUIRES}
+
+        # Register the handler factory service
+        self._registration = context.register_service(
+                                      constants.SERVICE_IPOPO_HANDLER_FACTORY,
+                                      _HandlerFactory(),
+                                      properties)
+
+
+    def stop(self, context):
+        """
+        Bundle stopped
+        """
+        # Unregister the service
+        self._registration.unregister()
+        self._registration = None
+
+# Declare the activator
+activator = _Activator()
+
+# ------------------------------------------------------------------------------
+
+class _RuntimeDependency(constants.DependencyHandler):
     """
     Manages a required dependency field when a component is running
     """
-    def __init__(self, stored_instance, field, requirement):
+    def __init__(self, field, requirement):
         """
         Sets up the dependency
-        
-        :param stored_instance: The iPOPO component StoredInstance object
+
         :param field: The injected field name
         :param requirement: The Requirement describing this dependency
         """
         # The internal state lock
         self._lock = threading.RLock()
 
-        # The iPOPO StoredInstance object
-        self._ipopo_instance = stored_instance
+        # The iPOPO StoredInstance object (given during manipulation)
+        self._ipopo_instance = None
 
         # The bundle context
-        self._context = self._ipopo_instance.bundle_context
+        self._context = None
 
         # The associated field
-        self.field = field
+        self._field = field
 
         # The underlying requirement
         self.requirement = requirement
@@ -80,11 +179,25 @@ class _RuntimeDependency(object):
         self._value = None
 
 
+    def manipulate(self, stored_instance, component_instance):
+        """
+        Stores the given StoredInstance bean.
+
+        :param stored_instance: The iPOPO component StoredInstance
+        :param component_instance: The component instance
+        """
+        # Store the stored instance...
+        self._ipopo_instance = stored_instance
+
+        # ... and the bundle context
+        self._context = stored_instance.bundle_context
+
+
     def clear(self):
         """
         Cleans up the manager. The manager can't be used after this method has
         been called
-        
+
         :return: The removed bindings (list) or None
         """
         self._lock = None
@@ -92,32 +205,39 @@ class _RuntimeDependency(object):
         self._context = None
         self.requirement = None
         self._value = None
-        self.field = None
+        self._field = None
 
 
     def get_bindings(self):
         """
         Retrieves the list of the references to the bound services
-        
+
         :return: A list of ServiceReferences objects
         """
         raise NotImplementedError
 
 
+    def get_field(self):
+        """
+        Returns the name of the field handled by this handler
+        """
+        return self._field
+
+
     def get_kinds(self):
         """
         Retrieves the kinds of this handler: 'dependency'
-        
+
         :return: the kinds of this handler
         """
-        return (constants.HANDLER_DEPENDENCY,)
+        return (constants.KIND_DEPENDENCY,)
 
 
     def get_value(self):
         """
         Retrieves the value to inject in the component (can be different of
         self._value)
-        
+
         :return: The value to inject
         """
         return self._value
@@ -134,7 +254,7 @@ class _RuntimeDependency(object):
     def on_service_arrival(self, svc_ref):
         """
         Called when a service has been registered in the framework
-        
+
         :param svc_ref: A service reference
         """
         raise NotImplementedError
@@ -143,7 +263,7 @@ class _RuntimeDependency(object):
     def on_service_departure(self, svc_ref):
         """
         Called when a service has been registered in the framework
-        
+
         :param svc_ref: A service reference
         """
         raise NotImplementedError
@@ -152,7 +272,7 @@ class _RuntimeDependency(object):
     def on_service_modify(self, svc_ref, old_properties):
         """
         Called when a service has been registered in the framework
-        
+
         :param svc_ref: A service reference
         :param old_properties: Previous properties values
         """
@@ -208,12 +328,11 @@ class SimpleDependency(_RuntimeDependency):
     """
     Manages a simple dependency field
     """
-    def __init__(self, stored_instance, field, requirement):
+    def __init__(self, field, requirement):
         """
         Sets up the dependency
         """
-        super(SimpleDependency, self).__init__(stored_instance, field,
-                                                requirement)
+        super(SimpleDependency, self).__init__(field, requirement)
 
         # We have only one reference to keep
         self.reference = None
@@ -223,7 +342,7 @@ class SimpleDependency(_RuntimeDependency):
         """
         Cleans up the manager. The manager can't be used after this method has
         been called
-        
+
         :return: The removed bindings (list) or None
         """
         self.reference = None
@@ -233,7 +352,7 @@ class SimpleDependency(_RuntimeDependency):
     def get_bindings(self):
         """
         Retrieves the list of the references to the bound services
-        
+
         :return: A list of ServiceReferences objects
         """
         result = []
@@ -247,7 +366,7 @@ class SimpleDependency(_RuntimeDependency):
     def on_service_arrival(self, svc_ref):
         """
         Called when a service has been registered in the framework
-        
+
         :param svc_ref: A service reference
         """
         with self._lock:
@@ -263,7 +382,7 @@ class SimpleDependency(_RuntimeDependency):
     def on_service_departure(self, svc_ref):
         """
         Called when a service has been unregistered from the framework
-        
+
         :param svc_ref: A service reference
         """
         with self._lock:
@@ -282,7 +401,7 @@ class SimpleDependency(_RuntimeDependency):
     def on_service_modify(self, svc_ref, old_properties):
         """
         Called when a service has been modified in the framework
-        
+
         :param svc_ref: A service reference
         :param old_properties: Previous properties values
         """
@@ -314,7 +433,7 @@ class SimpleDependency(_RuntimeDependency):
     def try_binding(self):
         """
         Searches for the required service if needed
-        
+
         :raise BundleException: Invalid ServiceReference found
         """
         with self._lock:
@@ -335,12 +454,12 @@ class AggregateDependency(_RuntimeDependency):
     """
     Manages an aggregated dependency field
     """
-    def __init__(self, stored_instance, field, requirement):
+    def __init__(self, field, requirement):
         """
         Sets up the dependency
         """
-        super(AggregateDependency, self).__init__(stored_instance, field,
-                                                   requirement)
+        super(AggregateDependency, self).__init__(field, requirement)
+
         # Reference -> Service
         self.services = {}
 
@@ -352,7 +471,7 @@ class AggregateDependency(_RuntimeDependency):
         """
         Cleans up the manager. The manager can't be used after this method has
         been called
-        
+
         :return: The removed bindings (list) or None
         """
         self.services.clear()
@@ -368,7 +487,7 @@ class AggregateDependency(_RuntimeDependency):
     def get_bindings(self):
         """
         Retrieves the list of the references to the bound services
-        
+
         :return: A list of ServiceReferences objects
         """
         with self._lock:
@@ -379,7 +498,7 @@ class AggregateDependency(_RuntimeDependency):
         """
         Retrieves the value to inject in the component (can be different of
         self._value)
-        
+
         :return: The value to inject
         """
         with self._lock:
@@ -403,7 +522,7 @@ class AggregateDependency(_RuntimeDependency):
     def on_service_arrival(self, svc_ref):
         """
         Called when a service has been registered in the framework
-        
+
         :param svc_ref: A service reference
         """
         with self._lock:
@@ -426,7 +545,7 @@ class AggregateDependency(_RuntimeDependency):
     def on_service_departure(self, svc_ref):
         """
         Called when a service has been unregistered from the framework
-        
+
         :param svc_ref: A service reference
         :return: A tuple (service, reference) if the service has been lost,
                  else None
@@ -451,7 +570,7 @@ class AggregateDependency(_RuntimeDependency):
     def on_service_modify(self, svc_ref, old_properties):
         """
         Called when a service has been modified in the framework
-        
+
         :param svc_ref: A service reference
         :param old_properties: Previous properties values
         :return: A tuple (added, (service, reference)) if the dependency has
@@ -487,7 +606,7 @@ class AggregateDependency(_RuntimeDependency):
     def try_binding(self):
         """
         Searches for the required service if needed
-        
+
         :raise BundleException: Invalid ServiceReference found
         """
         with self._lock:
