@@ -7,26 +7,25 @@ Provides the basic command parsing and execution support to make a Pelix shell.
 
 :author: Thomas Calmant
 :copyright: Copyright 2013, isandlaTech
-:license: GPLv3
+:license: Apache License 2.0
 :version: 0.2.3
-:status: Alpha
+:status: Beta
 
 ..
 
-    This file is part of iPOPO.
+    Copyright 2013 isandlaTech
 
-    iPOPO is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
+    Licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
+    You may obtain a copy of the License at
 
-    iPOPO is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    You should have received a copy of the GNU General Public License
-    along with iPOPO. If not, see <http://www.gnu.org/licenses/>.
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
 """
 
 # Module version
@@ -233,8 +232,14 @@ class IOHandler(object):
 
             # Write it
             self.write(line)
-            if line[-1] != '\n':
-                # Add the trailing new line
+
+            try:
+                if line[-1] != '\n':
+                    # Add the trailing new line
+                    self.write('\n')
+
+            except IndexError:
+                # Got an empty string
                 self.write('\n')
 
         self.flush()
@@ -663,6 +668,7 @@ class Shell(object):
 
         except Exception as ex:
             # Error
+            _logger.exception("Error calling %s.%s: %s", namespace, command, ex)
             io_handler.write_line("{0}: {1}", type(ex).__name__, str(ex))
             return False
 
