@@ -5,31 +5,32 @@ Pelix Utilities: Task pool
 
 :author: Thomas Calmant
 :copyright: Copyright 2013, isandlaTech
-:license: GPLv3
-:version: 0.5.4
-:status: Alpha
+:license: Apache License 2.0
+:version: 0.5.5
+:status: Beta
 
-    This file is part of iPOPO.
+..
 
-    iPOPO is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
+    Copyright 2013 isandlaTech
 
-    iPOPO is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+    Licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
+    You may obtain a copy of the License at
 
-    You should have received a copy of the GNU General Public License
-    along with iPOPO. If not, see <http://www.gnu.org/licenses/>.
+        http://www.apache.org/licenses/LICENSE-2.0
+
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
 """
 
 # Documentation strings format
 __docformat__ = "restructuredtext en"
 
 # Module version
-__version_info__ = (0, 5, 4)
+__version_info__ = (0, 5, 5)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # ------------------------------------------------------------------------------
@@ -68,7 +69,7 @@ class FutureResult(object):
         :param method: The method to execute
         :param args: Method positional arguments
         :param kwargs: Method keyword arguments
-        :raise: The exception raised by the method
+        :raise Exception: The exception raised by the method
         """
         # Normalize arguments
         if args is None:
@@ -135,6 +136,13 @@ class ThreadPool(object):
         self._done_event.set()
 
         # The task queue
+        try:
+            queue_size = int(queue_size)
+
+        except (TypeError, ValueError):
+            # Not a valid integer
+            queue_size = 0
+
         self._queue = queue.Queue(queue_size)
         self._timeout = timeout
         self.__lock = threading.Lock()
